@@ -1,38 +1,40 @@
-( cd opt/kde/lib ; rm -rf liboktetagui.so )
-( cd opt/kde/lib ; ln -sf liboktetagui.so.4 liboktetagui.so )
-( cd opt/kde/lib ; rm -rf libsuperkaramba.so.4 )
-( cd opt/kde/lib ; ln -sf libsuperkaramba.so.4.1.0 libsuperkaramba.so.4 )
-( cd opt/kde/lib ; rm -rf libsuperkaramba.so )
-( cd opt/kde/lib ; ln -sf libsuperkaramba.so.4 libsuperkaramba.so )
-( cd opt/kde/lib ; rm -rf liboktetacore.so.4 )
-( cd opt/kde/lib ; ln -sf liboktetacore.so.4.1.0 liboktetacore.so.4 )
+( cd opt/kde/bin ; rm -rf printer-applet )
+( cd opt/kde/bin ; ln -sf /opt/kde/share/apps/printer-applet/printer-applet.py printer-applet )
 ( cd opt/kde/lib ; rm -rf libkerfuffle.so )
 ( cd opt/kde/lib ; ln -sf libkerfuffle.so.4 libkerfuffle.so )
-( cd opt/kde/lib ; rm -rf libkerfuffle.so.4 )
-( cd opt/kde/lib ; ln -sf libkerfuffle.so.4.1.0 libkerfuffle.so.4 )
+( cd opt/kde/lib ; rm -rf liboktetacore.so.4 )
+( cd opt/kde/lib ; ln -sf liboktetacore.so.4.2.0 liboktetacore.so.4 )
+( cd opt/kde/lib ; rm -rf libsuperkaramba.so )
+( cd opt/kde/lib ; ln -sf libsuperkaramba.so.4 libsuperkaramba.so )
+( cd opt/kde/lib ; rm -rf liboktetagui.so )
+( cd opt/kde/lib ; ln -sf liboktetagui.so.4 liboktetagui.so )
+( cd opt/kde/lib ; rm -rf liboktetagui.so.4 )
+( cd opt/kde/lib ; ln -sf liboktetagui.so.4.2.0 liboktetagui.so.4 )
 ( cd opt/kde/lib ; rm -rf liboktetacore.so )
 ( cd opt/kde/lib ; ln -sf liboktetacore.so.4 liboktetacore.so )
-( cd opt/kde/lib ; rm -rf liboktetagui.so.4 )
-( cd opt/kde/lib ; ln -sf liboktetagui.so.4.1.0 liboktetagui.so.4 )
+( cd opt/kde/lib ; rm -rf libkerfuffle.so.4 )
+( cd opt/kde/lib ; ln -sf libkerfuffle.so.4.2.0 libkerfuffle.so.4 )
+( cd opt/kde/lib ; rm -rf libsuperkaramba.so.4 )
+( cd opt/kde/lib ; ln -sf libsuperkaramba.so.4.2.0 libsuperkaramba.so.4 )
+( cd opt/kde/share/doc/HTML/en/ark ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/ark ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kdf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kdf ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kgpg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kgpg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kfloppy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kfloppy ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcalc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcalc ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kwallet ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kwallet ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/superkaramba ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/superkaramba ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/ktimer ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/ktimer ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcharselect ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcharselect ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/okteta ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/okteta ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kgpg ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kgpg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/blockdevices ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/blockdevices ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/ark ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/ark ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kdf ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kdf ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/ktimer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/ktimer ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/okteta ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/okteta ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kcharselect ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kcharselect ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/superkaramba ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/superkaramba ; ln -sf /opt/kde/share/doc/HTML/en/common common )
